translate.misc.zipfileext

Package translate :: Package misc :: Module zipfileext |
[hide private]
[frames] | no frames]

# Module zipfileext

source code

extensions to zipfile standard module that will hopefully get included in future...

Classes | [hide private]
| ZipFileExt a ZipFile that can handle replacing objects

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: ZipFile, struct, structCentralDir, stringCentralDir, structEndArchive, stringEndArchive